@@ -3,6 +3,8 @@
 
 #include "location.h"
 
+#include "gpscontroller_p.h"
+
 #include <QObject>
 #include <QGeoPositionInfo>
 #include <QGeoPositionInfoSource>
@@ -15,11 +17,11 @@ class GpsController : public QObject
 
 public:
   GpsController();
+  GpsController( GpsControllerPrivate *gpsControllerPrivate );
 
   ~GpsController();
 
 public Q_SLOTS:
-  void updateLocation( QGeoPositionInfo positionInfo );
   void getGps();
   void useFakeGps( Location *fakeLocation );
   void useLiveGps();
@@ -28,9 +30,7 @@ Q_SIGNALS:
   void locationChanged( Location *newLocation );
 
 private:
-  QGeoPositionInfoSource *m_location;
-  Location               *m_currentLocation;
-  bool                    m_useFakeLocation;
+    GpsControllerPrivate *q;
 };
 
 #endif // GPSCONTROLLER_H
